#!/bin/bash
# Clone packages from $EUPS_PKGROOT to local storage.
# USAGE:
#    clone_repo.sh NAME-VERSION [NAME-VERSION ...]
#
# Say "module-1.2.3" does not compile, and you want to make modification
# to it before building it. Then, you should clone the package:
#
#    clone_repo.sh module-1.2.3
#
# The cloned package will be saved in `$workdir/hscpipe_build_dir/eupsrepo` ,
# where workdir is defined in `variables` created by `configure` .
#
# We hereafter assume you have changed directory to `$workdir/hscpipe_build_dir/eupsrepo` .
#
# The next thing to do is untar `products/module-1.2.3.eupspkg` .
# This is just a .tar.gz file, which can be untar'ed by:
#
#    cd products; tar -xzf module-1.2.3.eupspkg
#
# Now modify the source files, and re-package the source files by:
#
#    cd products; tar --owner=0 --group=0 -czf - module-1.2.3 > module-1.2.3.eupspkg
#
# Then, `build.sh` will read the package you have modified.

set -e

source "$(dirname "$0")"/variables

EUPS_PKGROOT="${eups_pkgroot_base_url%/}"/src
mirror_dir="${workdir:-/tmp}"/hscpipe_build_dir/eupsrepo

mkdir -p "$mirror_dir"/{manifests,products,tables,tags}

if ! [ -e "$mirror_dir"/config.txt ]
then
    curl -L "$EUPS_PKGROOT"/config.txt -o "$mirror_dir"/config.txt
fi

if ! [ -e "$mirror_dir"/tags/current.list ]
then
    curl -L "$EUPS_PKGROOT"/tags/current.list -o "$mirror_dir"/tags/current.list
fi

for package in "$@"
do
    curl -L "$EUPS_PKGROOT"/manifests/"$package".manifest -o "$mirror_dir"/manifests/"$package".manifest
    curl -L "$EUPS_PKGROOT"/products/"$package".eupspkg -o "$mirror_dir"/products/"$package".eupspkg
    curl -L "$EUPS_PKGROOT"/tables/"$package".table -o "$mirror_dir"/tables/"$package".table
done
